@@ -1,5 +1,8 @@
-require 'byebug/command'
-require 'irb'
+# frozen_string_literal: true
+
+require "byebug/command"
+require "irb"
+require "English"
 
 module Byebug
   #
@@ -13,23 +16,21 @@ module Byebug
     end
 
     def self.description
-      <<-EOD
+      <<-DESCRIPTION
         irb
 
         #{short_description}
-      EOD
+      DESCRIPTION
     end
 
     def self.short_description
-      'Starts an IRB session'
+      "Starts an IRB session"
     end
 
     def execute
-      unless processor.interface.instance_of?(LocalInterface)
-        return errmsg(pr('base.errors.only_local'))
-      end
+      return errmsg(pr("base.errors.only_local")) unless processor.interface.instance_of?(LocalInterface)
 
-      # @todo IRB tries to parse ARGV so we must clear it (see #197). Add a
+      # @todo IRB tries to parse $ARGV so we must clear it (see #197). Add a
       #   test case for it so we can remove this comment.
       with_clean_argv { IRB.start }
     end
@@ -37,12 +38,12 @@ module Byebug
     private
 
     def with_clean_argv
-      saved_argv = ARGV.dup
-      ARGV.clear
+      saved_argv = $ARGV.dup
+      $ARGV.clear
       begin
         yield
       ensure
-        ARGV.concat(saved_argv)
+        $ARGV.concat(saved_argv)
       end
     end
   end
