@@ -1,5 +1,7 @@
-require 'byebug/command'
-require 'byebug/helpers/eval'
+# frozen_string_literal: true
+
+require "byebug/command"
+require "byebug/helpers/eval"
 
 module Byebug
   #
@@ -13,26 +15,24 @@ module Byebug
     end
 
     def self.description
-      <<-EOD
+      <<-DESCRIPTION
         pry
 
         #{short_description}
-      EOD
+      DESCRIPTION
     end
 
     def self.short_description
-      'Starts a Pry session'
+      "Starts a Pry session"
     end
 
     def execute
-      unless processor.interface.instance_of?(LocalInterface)
-        return errmsg(pr('base.errors.only_local'))
-      end
+      return errmsg(pr("base.errors.only_local")) unless processor.interface.instance_of?(LocalInterface)
 
       begin
-        require 'pry'
+        require "pry"
       rescue LoadError
-        return errmsg(pr('pry.errors.not_installed'))
+        return errmsg(pr("pry.errors.not_installed"))
       end
 
       Pry.start(context.frame._binding)
