@@ -1,4 +1,6 @@
-require 'byebug/command'
+# frozen_string_literal: true
+
+require "byebug/command"
 
 module Byebug
   #
@@ -12,7 +14,7 @@ module Byebug
     end
 
     def self.description
-      <<-EOD
+      <<-DESCRIPTION
         tr[acevar] <variable> [[no]stop]
 
         #{short_description}
@@ -20,20 +22,17 @@ module Byebug
         If "stop" is specified, execution will stop every time the variable
         changes its value. If nothing or "nostop" is specified, execution won't
         stop, changes will just be logged in byebug's output.
-      EOD
+      DESCRIPTION
     end
 
     def self.short_description
-      'Enables tracing of a global variable'
+      "Enables tracing of a global variable"
     end
 
     def execute
       var = @match[1]
-      return errmsg(pr('trace.errors.needs_global_variable')) unless var
-
-      unless global_variables.include?(:"#{var}")
-        return errmsg(pr('trace.errors.var_is_not_global', name: var))
-      end
+      return errmsg(pr("trace.errors.needs_global_variable")) unless var
+      return errmsg(pr("trace.errors.var_is_not_global", name: var)) unless global_variables.include?(:"#{var}")
 
       stop = @match[2] && @match[2] !~ /nostop/
 
@@ -41,13 +40,13 @@ module Byebug
         trace_var(:"#{var}") { |val| on_change(var, val, stop) }
       end
 
-      puts pr('trace.messages.success', var: var)
+      puts pr("trace.messages.success", var: var)
     end
 
     private
 
     def on_change(name, value, stop)
-      puts pr('trace.messages.on_change', name: name, value: value)
+      puts pr("trace.messages.on_change", name: name, value: value)
 
       context.step_out(1, false) if stop
     end
