@@ -1,4 +1,6 @@
-require 'byebug/command'
+# frozen_string_literal: true
+
+require "byebug/command"
 
 module Byebug
   #
@@ -10,24 +12,24 @@ module Byebug
     end
 
     def self.description
-      <<-EOD
+      <<-DESCRIPTION
         untr[acevar] <variable>
 
         #{short_description}
-      EOD
+      DESCRIPTION
     end
 
     def self.short_description
-      'Stops tracing a global variable'
+      "Stops tracing a global variable"
     end
 
     def execute
       var = @match[1]
       if global_variables.include?(:"#{var}")
         untrace_var(:"#{var}")
-        puts pr('trace.messages.undo', var: var)
+        puts pr("trace.messages.undo", var: var)
       else
-        errmsg pr('trace.errors.not_global', var: var)
+        errmsg pr("trace.errors.not_global", var: var)
       end
     end
   end
