@@ -1,4 +1,6 @@
-require 'byebug/helpers/var'
+# frozen_string_literal: true
+
+require "byebug/helpers/var"
 
 module Byebug
   #
@@ -18,20 +20,20 @@ module Byebug
       end
 
       def self.description
-        <<-EOD
+        <<-DESCRIPTION
           v[ar] a[ll]
 
           #{short_description}
-        EOD
+        DESCRIPTION
       end
 
       def self.short_description
-        'Shows local, global and instance variables of self.'
+        "Shows local, global and instance variables of self."
       end
 
       def execute
         var_global
-        var_instance('self')
+        var_instance("self")
         var_local
       end
     end
